lavuelib.plugins package — LaVue 2.76.0 documentation

# lavuelib.plugins package

## lavuelib.plugins.filters module

set of image sources

class `lavuelib.plugins.filters.` `HGap`(configuration=None)

  Bases: `object`

  Horizontal gap filter

  constructor

  Parameters

    configuration (`str`) – JSON list with horizontal gap pixels to add

class `lavuelib.plugins.filters.` `VGap`(configuration=None)

  Bases: `object`

  Vertical gap filter

  constructor

  Parameters

    configuration (`str`) – JSON list with vertical gap pixels to add

class `lavuelib.plugins.filters.` `WeightedSum`(configuration=None)

  Bases: `object`

  Weighted sum of channel images

  constructor

  Parameters

    configuration (`str`) – JSON list of channel image weights

`lavuelib.plugins.filters.` `rot45`(image, imagename, metadata, imagewg)

  rotate image by 45 deg

  Parameters

    - image (`numpy.ndarray`) – numpy array with an image

    - imagename (`str`) – image name

    - metadata (`str`) – JSON dictionary with metadata

    - imagewg (`lavuelib.imageWidget.ImageWidget`) – image wigdet

  Returns

    numpy array with an image

  Return type

    `numpy.ndarray` or None